@@ -55,6 +55,11 @@ namespace LongoMatch.Video.Utils
 			} else {
 				this.outputFilepath = Path.ChangeExtension(inputFile.FilePath,
 				                                           GetExtension(muxer));
+				if (this.outputFilepath == inputFile.FilePath) {
+					this.outputFilepath = Path.ChangeExtension(inputFile.FilePath,
+					                                           "1." + GetExtension(muxer));
+				}
+
 			}
 			this.multimedia = new MultimediaFactory();
 		}
@@ -74,7 +79,7 @@ namespace LongoMatch.Video.Utils
 			
 			/* Add label and progress bar */
 			box = new VBox();
-			label = new Label(Catalog.GetString("Remuxing file, this might take while..."));
+			label = new Label(Catalog.GetString("Remuxing file, this might take a while..."));
 			box.PackStart(label);
 			pb = new ProgressBar();
 			box.PackStart(pb);
