@@ -55,11 +55,6 @@ namespace LongoMatch.Gui.Component
 			Sensitive = true;
 		}
 		
-		~CoordinatesTagger() {
-			if (source != null)
-				source.Destroy();
-		}
-		
 		public new bool Sensitive {
 			get;
 			set;
@@ -193,6 +188,13 @@ namespace LongoMatch.Gui.Component
 			}
 		}
 		
+		protected override void OnDestroyed ()
+		{
+			base.OnDestroyed ();
+			if (source != null)
+				source.Destroy();
+		}
+		
 		protected virtual void OnDrawingareaButtonPressEvent(object o, Gtk.ButtonPressEventArgs args)
 		{
 			if (!Sensitive)
