@@ -21,6 +21,7 @@
 using System;
 using System.Collections.Generic;
 using Gtk;
+using Mono.Unix;
 using LongoMatch.Common;
 using LongoMatch.Gui.Dialog;
 using LongoMatch.Gui.Popup;
@@ -29,8 +30,9 @@ using LongoMatch.Interfaces;
 using LongoMatch.Store;
 using LongoMatch.Store.Templates;
 using LongoMatch.Video.Utils;
-using Mono.Unix;
 using LongoMatch.Gui.Helpers;
+using Misc = LongoMatch.Gui.Helpers.Misc;
+using LongoMatch.Multimedia.Utils;
 
 namespace LongoMatch.Gui.Component
 {
@@ -56,8 +58,7 @@ namespace LongoMatch.Gui.Component
 		ITemplatesService service;
 		ProjectType useType;
 		List<Device> videoDevices;
-		ListStore videoStandardList;
-		ListStore encProfileList;
+		ListStore videoStandardList, encProfileList, qualList;
 		private const string DV_SOURCE = "DV Source";
 		private const string GCONF_SOURCE = "GConf Source";
 
@@ -241,8 +242,6 @@ namespace LongoMatch.Gui.Component
 				CaptureSettings s = new CaptureSettings();
 				
 				encSettings.OutputFile = fileEntry.Text;
-				encSettings.AudioBitrate = (uint)audiobitratespinbutton.Value;
-				encSettings.VideoBitrate = (uint)videobitratespinbutton.Value;
 				if (useType == ProjectType.CaptureProject) {
 					s.CaptureSourceType = videoDevices[devicecombobox.Active].DeviceType;
 					s.DeviceID = videoDevices[devicecombobox.Active].ID;
@@ -251,17 +250,21 @@ namespace LongoMatch.Gui.Component
 					s.DeviceID = urientry.Text;
 				}
 				
+				/* Get quality info */
+				qualitycombobox.GetActiveIter(out iter);
+				encSettings.EncodingQuality = (EncodingQuality) qualList.GetValue(iter, 1);
+				
 				/* Get size info */
-				sizecombobox.GetActiveIter(out iter);
+				imagecombobox.GetActiveIter(out iter);
 				encSettings.VideoStandard = (VideoStandard) videoStandardList.GetValue(iter, 1);
 			
 				/* Get encoding profile info */
-				videoformatcombobox.GetActiveIter(out iter);
+				encodingcombobox.GetActiveIter(out iter);
 				encSettings.EncodingProfile = (EncodingProfile) encProfileList.GetValue(iter, 1);
 				
 				/* FIXME: Configure with the UI */
-				encSettings.Framerate_n = 25;
-				encSettings.Framerate_d = 1;
+				encSettings.Framerate_n = Config.FPS_N;
+				encSettings.Framerate_d = Config.FPS_D;
 				
 				s.EncodingSettings = encSettings;
 				return s;
@@ -422,25 +425,9 @@ namespace LongoMatch.Gui.Component
 		}
 
 		private void FillFormats() {
-			videoStandardList = new ListStore(typeof(string), typeof (VideoStandard));
-			videoStandardList.AppendValues(VideoStandards.Original.Name, VideoStandards.Original);
-			videoStandardList.AppendValues(VideoStandards.P240_4_3.Name, VideoStandards.P240_4_3);
-			videoStandardList.AppendValues(VideoStandards.P240_16_9.Name, VideoStandards.P240_16_9);
-			videoStandardList.AppendValues(VideoStandards.P480_4_3.Name, VideoStandards.P480_4_3);
-			videoStandardList.AppendValues(VideoStandards.P480_16_9.Name, VideoStandards.P480_16_9);
-			videoStandardList.AppendValues(VideoStandards.P720_4_3.Name, VideoStandards.P720_4_3);
-			videoStandardList.AppendValues(VideoStandards.P720_16_9.Name, VideoStandards.P720_16_9);
-			videoStandardList.AppendValues(VideoStandards.P1080_4_3.Name, VideoStandards.P1080_4_3);
-			videoStandardList.AppendValues(VideoStandards.P1080_16_9.Name, VideoStandards.P1080_16_9);
-			sizecombobox.Model = videoStandardList;
-			sizecombobox.Active = 0;
-
-			encProfileList = new ListStore(typeof(string), typeof (EncodingProfile));
-			encProfileList.AppendValues(EncodingProfiles.MP4.Name, EncodingProfiles.MP4);
-			encProfileList.AppendValues(EncodingProfiles.Avi.Name, EncodingProfiles.Avi);
-			encProfileList.AppendValues(EncodingProfiles.WebM.Name, EncodingProfiles.WebM);
-			videoformatcombobox.Model = encProfileList;
-			videoformatcombobox.Active = 0;
+			videoStandardList = Misc.FillImageFormat (imagecombobox, Config.CaptureVideoStandard);
+			encProfileList = Misc.FillEncodingFormat (encodingcombobox, Config.CaptureEncodingProfile);
+			qualList = Misc.FillQuality (qualitycombobox, Config.CaptureEncodingQuality);
 		}
 		
 		private void StartEditor(TemplateEditorDialog editor) {
@@ -456,75 +443,57 @@ namespace LongoMatch.Gui.Component
 
 		protected virtual void OnOpenbuttonClicked(object sender, System.EventArgs e)
 		{
-			FileChooserDialog fChooser = null;
-
 			if(useType == ProjectType.CaptureProject || useType == ProjectType.URICaptureProject) {
-				fChooser = new FileChooserDialog(Catalog.GetString("Output file"),
-				                                 (Gtk.Window)this.Toplevel,
-				                                 FileChooserAction.Save,
-				                                 "gtk-cancel",ResponseType.Cancel,
-				                                 "gtk-save",ResponseType.Accept);
-				fChooser.SetCurrentFolder(Config.VideosDir);
-				fChooser.DoOverwriteConfirmation = true;
-				if(fChooser.Run() == (int)ResponseType.Accept)
-					fileEntry.Text = fChooser.Filename;
-				fChooser.Destroy();
+				string filename;
+				
+				filename = FileChooserHelper.SaveFile (this, Catalog.GetString("Output file"),
+				                                       "Capture.mp4", Config.VideosDir, "MP4",
+				                                       new string[] {"*.mp4"});
+				if (filename != null)
+					fileEntry.Text = System.IO.Path.ChangeExtension(filename, "mp4");
 
 			} else	{
-				fChooser = new FileChooserDialog(Catalog.GetString("Open file..."),
-				                                 (Gtk.Window)this.Toplevel,
-				                                 FileChooserAction.Open,
-				                                 "gtk-cancel",ResponseType.Cancel,
-				                                 "gtk-open",ResponseType.Accept);
-
-				fChooser.SetCurrentFolder(System.Environment.GetFolderPath(Environment.SpecialFolder.Personal));
-
-				if(fChooser.Run() == (int)ResponseType.Accept) {
-					MessageDialog md=null;
-					string filename = fChooser.Filename;
-					fChooser.Destroy();
+				MessageDialog md=null;
+				string folder, filename;
+				
+				folder = System.Environment.GetFolderPath(Environment.SpecialFolder.Personal);
+				filename = FileChooserHelper.OpenFile (this, Catalog.GetString("Open file"),
+				                                       null, folder, null, null);                             
+				if (filename == null)
+					return;
 					
-					if (MpegRemuxer.FileIsMpeg(filename) &&
-					    MpegRemuxer.AskForConversion(this.Toplevel as Gtk.Window)) {
-						var remux = new MpegRemuxer(filename);
-						var newFilename = remux.Remux(this.Toplevel as Gtk.Window);
-						if (newFilename != null)
-							filename = newFilename;
-					}
+				try {
+					md = new MessageDialog((Gtk.Window)this.Toplevel,
+					                       DialogFlags.Modal,
+					                       MessageType.Info,
+					                       Gtk.ButtonsType.None,
+					                       Catalog.GetString("Analyzing video file:")+"\n"+filename);
+					md.Icon=Stetic.IconLoader.LoadIcon(this, "longomatch", Gtk.IconSize.Dialog);
+					md.Show();
 					
-					if (AsfRemuxer.FileIsAsf(filename) &&
-					    MpegRemuxer.AskForConversion(this.Toplevel as Gtk.Window)) {
-						var remux = new AsfRemuxer(filename);
-						var newFilename = remux.Remux(this.Toplevel as Gtk.Window);
-						if (newFilename != null)
-							filename = newFilename;
-					}
-					
-					try {
-						md = new MessageDialog((Gtk.Window)this.Toplevel,
-						                       DialogFlags.Modal,
-						                       MessageType.Info,
-						                       Gtk.ButtonsType.None,
-						                       Catalog.GetString("Analyzing video file:")+"\n"+filename);
-						md.Icon=Stetic.IconLoader.LoadIcon(this, "longomatch", Gtk.IconSize.Dialog);
-						md.Show();
-						mFile = PreviewMediaFile.DiscoverFile(filename);
-						if(!mFile.HasVideo || mFile.VideoCodec == "")
-							throw new Exception(Catalog.GetString("This file doesn't contain a video stream."));
-						if(mFile.HasVideo && mFile.Length == 0)
-							throw new Exception(Catalog.GetString("This file contains a video stream but its length is 0."));
-
-
-						fileEntry.Text = filename;
-					}
-					catch(Exception ex) {
-						MessagesHelpers.ErrorMessage (this, ex.Message);
-					}
-					finally {
-						md.Destroy();
+					mFile = PreviewMediaFile.DiscoverFile(filename);
+					if(!mFile.HasVideo || mFile.VideoCodec == "")
+						throw new Exception(Catalog.GetString("This file doesn't contain a video stream."));
+					if(mFile.HasVideo && mFile.Length == 0)
+						throw new Exception(Catalog.GetString("This file contains a video stream but its length is 0."));
+					if (GStreamer.FileNeedsRemux(mFile)) {
+						string q = Catalog.GetString("The file you are trying to load is not properly supported. " +
+						                             "Would you like to convert it into a more suitable format?");
+						if (MessagesHelpers.QuestionMessage (this, q)) {
+							var remux = new Remuxer(mFile);
+							var newFilename = remux.Remux(this.Toplevel as Gtk.Window);
+							if (newFilename != null)
+								mFile = PreviewMediaFile.DiscoverFile (newFilename);
+						}
 					}
+					fileEntry.Text = mFile.FilePath;
+				}
+				catch(Exception ex) {
+					MessagesHelpers.ErrorMessage (this, ex.Message);
+				}
+				finally {
+					md.Destroy();
 				}
-				fChooser.Destroy();
 			}
 		}
 
