@@ -226,6 +226,9 @@ namespace LongoMatch.DB
 			} finally {
 				CloseDB(db);
 			}
+			if (ret != null && FixProjectCoordinates (ret)) {
+				UpdateProject (ret);
+			}
 			return ret;
 		}
 
@@ -486,6 +489,55 @@ namespace LongoMatch.DB
 			}
 		}
 
+		void FixCoordinates (Project project, int old_width, string backgroundName)
+		{
+			List<Coordinates> coords = null;
+			Image image = null;
+			
+			if (backgroundName == Constants.FIELD_BACKGROUND) {
+				image = Config.FieldBackground;
+				project.Categories.FieldBackground = image; 
+				coords =  project.AllPlays().Select(p => p.FieldPosition).ToList();
+			} else if (backgroundName == Constants.HALF_FIELD_BACKGROUND) {
+				image = Config.HalfFieldBackground;
+				project.Categories.HalfFieldBackground = image; 
+				coords = project.AllPlays().Select(p => p.HalfFieldPosition).ToList();
+			} else if (backgroundName == Constants.GOAL_BACKGROUND) {
+				image = Config.GoalBackground;
+				project.Categories.GoalBackground = image;
+			}
+			
+			if (coords != null) {
+				int new_width;
+				
+				new_width = image.Width;
+				foreach (Coordinates c in coords) {
+					float scale = (float) new_width / old_width;
+					foreach (Point p in c) {
+						p.X = (int) (p.X * scale);
+						p.Y = (int) (p.Y * scale);
+					}
+				}
+			}
+		}
+		
+		bool FixProjectCoordinates (Project project) {
+			bool save = false;
+			
+			if (project.Categories.FieldBackground == null) {
+				FixCoordinates (project, 2078, Constants.FIELD_BACKGROUND);
+				save = true;
+			}
+			if (project.Categories.HalfFieldBackground == null) {
+				FixCoordinates (project, 2078, Constants.HALF_FIELD_BACKGROUND);
+				save = true;
+			}
+			if (project.Categories.GoalBackground == null) {
+				FixCoordinates (project, 400, Constants.GOAL_BACKGROUND);
+				save = true;
+			}
+			return save;
+		}
 
 		/* Dummy class to allow having a single instance of BackupDateTime in the DB and make it
 		 * easIer to query */
