@@ -444,7 +444,7 @@ GstElement * lgm_create_video_encoder (VideoEncoderType type, guint quality,
       encoder = gst_element_factory_make ("ffenc_mpeg4", "video-encoder");
       g_object_set (encoder, "pass", 512,
           "max-key-interval", -1,
-          "bitrate", 4000000 * quality / 100, NULL);
+          "bitrate", quality * 1000 , NULL);
       name = "FFmpeg mpeg4 video encoder";
       break;
 
@@ -452,7 +452,7 @@ GstElement * lgm_create_video_encoder (VideoEncoderType type, guint quality,
       encoder = gst_element_factory_make ("xvidenc", "video-encoder");
       g_object_set (encoder, "pass", 3,
           "profile", 146, "max-key-interval", -1,
-          "quantizer", quality * 31 / 100, NULL);
+          "bitrate", quality * 1000, NULL);
       name = "Xvid video encoder";
       break;
 
@@ -460,7 +460,7 @@ GstElement * lgm_create_video_encoder (VideoEncoderType type, guint quality,
       encoder = gst_element_factory_make ("x264enc", "video-encoder");
       g_object_set (encoder, "key-int-max", 25, "pass", 17,
           "speed-preset", 3,
-          "bitrate", 4000 * quality / 100, NULL);
+          "bitrate", quality, NULL);
       name = "X264 video encoder";
       break;
 
@@ -468,7 +468,7 @@ GstElement * lgm_create_video_encoder (VideoEncoderType type, guint quality,
       encoder = gst_element_factory_make ("theoraenc", "video-encoder");
       g_object_set (encoder, "keyframe-auto", FALSE,
           "keyframe-force", 25,
-          "quality", quality * 63 / 100, NULL);
+          "bitrate", quality, NULL);
       name = "Theora video encoder";
       break;
 
@@ -477,7 +477,7 @@ GstElement * lgm_create_video_encoder (VideoEncoderType type, guint quality,
       encoder = gst_element_factory_make ("vp8enc", "video-encoder");
       g_object_set (encoder, "speed", 2, "threads", 8,
           "max-keyframe-distance", 25,
-          "quality", (gdouble) quality * 10 / 100, NULL);
+          "bitrate", (gdouble) quality * 1000, NULL);
       name = "VP8 video encoder";
       break;
 
@@ -503,21 +503,20 @@ GstElement * lgm_create_audio_encoder (AudioEncoderType type, guint quality,
   switch (type) {
     case AUDIO_ENCODER_MP3:
       encoder = gst_element_factory_make ("lamemp3enc", "audio-encoder");
-      g_object_set (encoder, "target", 0,
-          "quality", (gfloat) quality * 10 / 100, NULL);
+      g_object_set (encoder, "target", 0, "quality", (gfloat)4, NULL);
       name = "Mp3 audio encoder";
       break;
 
     case AUDIO_ENCODER_AAC:
       encoder = gst_element_factory_make ("faac", "audio-encoder");
-      g_object_set (encoder, "bitrate", quality *  320000 / 100, NULL);
+      g_object_set (encoder, "bitrate", 128000, NULL);
       name = "AAC audio encoder";
       break;
 
     case AUDIO_ENCODER_VORBIS:
     default:
       encoder = gst_element_factory_make ("vorbisenc", "audio-encoder");
-      g_object_set (encoder, "quality", (gfloat) quality / 100, NULL);
+      g_object_set (encoder, "quality", 0.3, NULL);
       name = "Vorbis audio encoder";
       break;
   }
